<?xml version="1.0" encoding="utf-8"?>
<!DOCTYPE TS>
<TS version="2.0" language="es_MX">
<context>
    <name>MainWindow</name>
    <message>
        <source>Themes or indent schemes not found.
Check installation.</source>
        <translation type="obsolete">Temas o esquemas de indentación no encontrados
Revise su instalación.</translation>
    </message>
    <message>
        <location filename="mainwindow.cpp" line="84"/>
        <source>Initialization error</source>
        <translation>Error de inicialización</translation>
    </message>
    <message>
        <location filename="mainwindow.cpp" line="85"/>
        <source>Could not find syntax definitions. Check installation.</source>
        <translation>Definiciones de sintaxis no encontradas.
Revise su instalacion.</translation>
    </message>
    <message>
        <location filename="mainwindow.cpp" line="143"/>
        <source>Select one or more files to open</source>
        <translation type="unfinished"></translation>
    </message>
    <message>
        <location filename="mainwindow.cpp" line="183"/>
        <source>Select destination directory</source>
        <translation type="unfinished"></translation>
    </message>
    <message>
        <location filename="mainwindow.cpp" line="668"/>
        <source>Tags file error</source>
        <translation>Error de archivo de etiquetas</translation>
    </message>
    <message>
        <location filename="mainwindow.cpp" line="669"/>
        <source>Could not read tags information in &quot;%1&quot;</source>
        <translation>No se pudieron leer las etiquetas de &quot;%1&quot;</translation>
    </message>
    <message>
        <location filename="mainwindow.cpp" line="686"/>
        <location filename="mainwindow.cpp" line="717"/>
        <source>Output error</source>
        <translation>Error de salida</translation>
    </message>
    <message>
        <location filename="mainwindow.cpp" line="686"/>
        <source>Output directory does not exist!</source>
        <translation>¡Directorio de salida no existe!</translation>
    </message>
    <message>
        <location filename="mainwindow.cpp" line="717"/>
        <source>You must define a style output file!</source>
        <translation>¡Debe especificar un archivo de estilo de salida!</translation>
    </message>
    <message>
        <location filename="mainwindow.cpp" line="756"/>
        <source>Language definition error</source>
        <translation>Error de definición de lenguaje</translation>
    </message>
    <message>
        <location filename="mainwindow.cpp" line="757"/>
        <source>Invalid regular expression in %1:
%2</source>
        <translation>Expresión regular inválida en %1:
%2</translation>
    </message>
    <message>
        <location filename="mainwindow.cpp" line="761"/>
        <source>Unknown syntax</source>
        <translation>Sintaxis desconocida</translation>
    </message>
    <message>
        <location filename="mainwindow.cpp" line="761"/>
        <source>Could not convert %1</source>
        <translation>No se pudo convertir %1</translation>
    </message>
    <message>
        <location filename="mainwindow.cpp" line="830"/>
        <source>Converted %1 files in %2 ms</source>
        <translation>Se convirtieron%1 archivos en %2 ms</translation>
    </message>
    <message>
        <location filename="mainwindow.cpp" line="915"/>
        <source>Conversion of &quot;%1&quot; not possible.</source>
        <translation>No es posible la conversión de &quot;%1&quot;.</translation>
    </message>
    <message>
        <location filename="mainwindow.cpp" line="915"/>
        <location filename="mainwindow.cpp" line="1019"/>
        <location filename="mainwindow.cpp" line="1042"/>
        <source>clipboard data</source>
        <translation type="unfinished"></translation>
    </message>
    <message>
        <location filename="mainwindow.cpp" line="974"/>
        <source>%1 options</source>
        <translation type="unfinished"></translation>
    </message>
    <message>
        <location filename="mainwindow.cpp" line="1018"/>
        <source>Preview (%1):</source>
        <translation>Previsualización (%1):</translation>
    </message>
    <message>
        <location filename="mainwindow.cpp" line="1021"/>
        <source>Current syntax: %1</source>
        <translation>Sintaxis actual: %1</translation>
    </message>
    <message>
        <location filename="mainwindow.cpp" line="1042"/>
        <source>Preview of &quot;%1&quot; not possible.</source>
        <translation>No es posible previsualizar &quot;%1&quot;.</translation>
    </message>
    <message>
        <location filename="mainwindow.cpp" line="1053"/>
        <source>Choose a ctags file</source>
        <translation>Elija un archivo de ctags</translation>
    </message>
    <message>
        <location filename="mainwindow.cpp" line="1079"/>
        <location filename="mainwindow.cpp" line="1083"/>
        <location filename="mainwindow.cpp" line="1087"/>
        <location filename="mainwindow.cpp" line="1092"/>
        <source>Choose a style include file</source>
        <translation>Elija un archivo de inclusión de estilo</translation>
    </message>
    <message>
        <location filename="mainwindow.cpp" line="1098"/>
        <source>About providing translations</source>
        <translation type="unfinished"></translation>
    </message>
    <message>
        <location filename="mainwindow.cpp" line="1099"/>
        <source>The GUI was developed using the Qt toolkit, and translations may be provided using the tools Qt Linguist and lrelease.
The highlight.ts file for Linguist resides in the src/gui-qt subdirectory.
The qm file generated by lrelease has to be saved in gui-files/l10n.

Please send a note to as (at) andre-simon (dot) de if you have issues during translating or if you have finished or updated a translation.</source>
        <translation type="unfinished"></translation>
    </message>
    <message>
        <location filename="mainwindow.cpp" line="1156"/>
        <source>Select one or more plug-ins</source>
        <translation type="unfinished"></translation>
    </message>
</context>
<context>
    <name>MainWindowClass</name>
    <message>
        <location filename="mainwindow.ui" line="160"/>
        <source>Choose the source code files you want to convert.</source>
        <translation>Elijir los archivos fuente que desea convertir.</translation>
    </message>
    <message>
        <location filename="mainwindow.ui" line="166"/>
        <source>Choose input files</source>
        <translation>Elijir archivos de entrada</translation>
    </message>
    <message>
        <location filename="mainwindow.ui" line="192"/>
        <source>List of input files.</source>
        <translation>Lista de archivos de entrada.</translation>
    </message>
    <message>
        <location filename="mainwindow.ui" line="216"/>
        <source>Remove the selected input files.</source>
        <translation>Remover los archivos de entrada seleccionados.</translation>
    </message>
    <message>
        <location filename="mainwindow.ui" line="219"/>
        <location filename="mainwindow.ui" line="506"/>
        <source>Clear selection</source>
        <translation>Remover seleccionados</translation>
    </message>
    <message>
        <location filename="mainwindow.ui" line="226"/>
        <source>Remove all input files.</source>
        <translation>Remover todos los archivos de entrada.</translation>
    </message>
    <message>
        <location filename="mainwindow.ui" line="229"/>
        <location filename="mainwindow.ui" line="516"/>
        <source>Clear all</source>
        <translation>Remover todos</translation>
    </message>
    <message>
        <source>Output destination</source>
        <translation type="obsolete">Destino de salida</translation>
    </message>
    <message>
        <location filename="mainwindow.ui" line="268"/>
        <source>Output directory</source>
        <translation>Directorio de salida</translation>
    </message>
    <message>
        <location filename="mainwindow.ui" line="287"/>
        <source>Select the output directory.</source>
        <translation>Elijir el directorio de salida.</translation>
    </message>
    <message>
        <location filename="mainwindow.ui" line="290"/>
        <location filename="mainwindow.ui" line="985"/>
        <location filename="mainwindow.ui" line="1096"/>
        <location filename="mainwindow.ui" line="1309"/>
        <location filename="mainwindow.ui" line="1405"/>
        <location filename="mainwindow.ui" line="1641"/>
        <source>...</source>
        <translation>...</translation>
    </message>
    <message>
        <location filename="mainwindow.ui" line="299"/>
        <source>Save output in the input file directories.</source>
        <translation>Guardar salida en los directorios de entrada de cada archivo.</translation>
    </message>
    <message>
        <location filename="mainwindow.ui" line="302"/>
        <source>Write to source directories</source>
        <translation>Guardar a los directorios de origen</translation>
    </message>
    <message>
        <source>Output options</source>
        <translation type="obsolete">Opciones de salida</translation>
    </message>
    <message>
        <location filename="mainwindow.ui" line="561"/>
        <source>General</source>
        <translation>General</translation>
    </message>
    <message>
        <location filename="mainwindow.ui" line="581"/>
        <source>Output format:</source>
        <translation>Formato de salida:</translation>
    </message>
    <message>
        <location filename="mainwindow.ui" line="603"/>
        <source>Choose an output format.</source>
        <translation>Elija un formato de salida.</translation>
    </message>
    <message>
        <location filename="mainwindow.ui" line="607"/>
        <source>HTML</source>
        <translation></translation>
    </message>
    <message>
        <location filename="mainwindow.ui" line="612"/>
        <source>XHTML</source>
        <translation></translation>
    </message>
    <message>
        <location filename="mainwindow.ui" line="617"/>
        <source>LaTeX</source>
        <translation></translation>
    </message>
    <message>
        <location filename="mainwindow.ui" line="622"/>
        <source>TeX</source>
        <translation></translation>
    </message>
    <message>
        <location filename="mainwindow.ui" line="627"/>
        <source>RTF</source>
        <translation></translation>
    </message>
    <message>
        <location filename="mainwindow.ui" line="632"/>
        <source>SVG</source>
        <translation></translation>
    </message>
    <message>
        <location filename="mainwindow.ui" line="656"/>
        <source>Add line numbers to the output.</source>
        <translation>Agregar números de linea a la salida.</translation>
    </message>
    <message>
        <location filename="mainwindow.ui" line="659"/>
        <source>Add line numbers</source>
        <translation>Agregar números de linea</translation>
    </message>
    <message>
        <location filename="mainwindow.ui" line="679"/>
        <source>Select the line number width.</source>
        <translation>Seleccione el ancho de número de linea.</translation>
    </message>
    <message>
        <location filename="mainwindow.ui" line="700"/>
        <source>Fill leading space of line numbers with zeroes.</source>
        <translation>Llenar espacio antes de los números de lineas con ceros.</translation>
    </message>
    <message>
        <location filename="mainwindow.ui" line="703"/>
        <source>Pad with zeroes</source>
        <translation>Rellenar con ceros</translation>
    </message>
    <message>
        <location filename="mainwindow.ui" line="716"/>
        <source>Generate output without document header and footer.</source>
        <translation>Generar documento de salida con cabecera y pie de página.</translation>
    </message>
    <message>
        <location filename="mainwindow.ui" line="719"/>
        <source>Omit header and footer</source>
        <translation>Omitir cabecera y pie de página</translation>
    </message>
    <message>
        <location filename="mainwindow.ui" line="726"/>
        <source>Test if input data is not binary.
Removes Unicode BOM mark.</source>
        <translation>Probar si los datos de entrada no son binarios.
Remueve marca BOM de Unicode.</translation>
    </message>
    <message>
        <location filename="mainwindow.ui" line="730"/>
        <source>Validate input data</source>
        <translation>Validar datos de entrada</translation>
    </message>
    <message>
        <location filename="mainwindow.ui" line="739"/>
        <source>Set the output file ancoding.</source>
        <translation>Ajuste la codificación del archivo de salida.</translation>
    </message>
    <message>
        <source>Encoding:</source>
        <translation type="obsolete">Codificación:</translation>
    </message>
    <message>
        <location filename="mainwindow.ui" line="749"/>
        <source>Select or define the encoding.
The result has to match the input file encoding.</source>
        <translation>Elija o defina la codificación.
El resultado tiene que corresponder a la codificación del archivo de entrada.</translation>
    </message>
    <message>
        <location filename="mainwindow.ui" line="760"/>
        <source>ISO-8859-1</source>
        <translation></translation>
    </message>
    <message>
        <location filename="mainwindow.ui" line="765"/>
        <source>ISO-8859-2</source>
        <translation></translation>
    </message>
    <message>
        <location filename="mainwindow.ui" line="770"/>
        <source>ISO-8859-3</source>
        <translation></translation>
    </message>
    <message>
        <location filename="mainwindow.ui" line="775"/>
        <source>ISO-8859-4</source>
        <translation></translation>
    </message>
    <message>
        <location filename="mainwindow.ui" line="780"/>
        <source>ISO-8859-5</source>
        <translation></translation>
    </message>
    <message>
        <location filename="mainwindow.ui" line="785"/>
        <source>ISO-8859-6</source>
        <translation></translation>
    </message>
    <message>
        <location filename="mainwindow.ui" line="790"/>
        <source>ISO-8859-7</source>
        <translation></translation>
    </message>
    <message>
        <location filename="mainwindow.ui" line="795"/>
        <source>ISO-8859-8</source>
        <translation></translation>
    </message>
    <message>
        <location filename="mainwindow.ui" line="800"/>
        <source>ISO-8859-9</source>
        <translation></translation>
    </message>
    <message>
        <location filename="mainwindow.ui" line="805"/>
        <source>ISO-8859-10</source>
        <translation></translation>
    </message>
    <message>
        <location filename="mainwindow.ui" line="810"/>
        <source>ISO-8859-11</source>
        <translation></translation>
    </message>
    <message>
        <location filename="mainwindow.ui" line="815"/>
        <source>ISO-8859-12</source>
        <translation></translation>
    </message>
    <message>
        <location filename="mainwindow.ui" line="820"/>
        <source>ISO-8859-13</source>
        <translation></translation>
    </message>
    <message>
        <location filename="mainwindow.ui" line="825"/>
        <source>ISO-8859-14</source>
        <translation></translation>
    </message>
    <message>
        <location filename="mainwindow.ui" line="830"/>
        <source>ISO-8859-15</source>
        <translation></translation>
    </message>
    <message>
        <location filename="mainwindow.ui" line="835"/>
        <source>UTF-8</source>
        <translation></translation>
    </message>
    <message>
        <location filename="mainwindow.ui" line="859"/>
        <source>Output specific</source>
        <translation>Esoecificas de salida</translation>
    </message>
    <message>
        <source>HTML options</source>
        <translation type="obsolete">Opciones de HTML</translation>
    </message>
    <message>
        <source>Style</source>
        <translation type="obsolete">Hoja de estilo</translation>
    </message>
    <message>
        <location filename="mainwindow.ui" line="908"/>
        <location filename="mainwindow.ui" line="1239"/>
        <location filename="mainwindow.ui" line="1335"/>
        <location filename="mainwindow.ui" line="1571"/>
        <source>Include the style information in each output file.</source>
        <translation>Incluir la información de estilo en cada archivo de salida.</translation>
    </message>
    <message>
        <location filename="mainwindow.ui" line="911"/>
        <location filename="mainwindow.ui" line="1574"/>
        <source>Embed style (CSS)</source>
        <translation>Incrustar estilo (CSS)</translation>
    </message>
    <message>
        <location filename="mainwindow.ui" line="924"/>
        <source>Add CSS information to each tag (do not use CSS class definitions).</source>
        <translation>Agregar información de CSS a cada etiqueta (no utilizar definiciones de clase de CSS).</translation>
    </message>
    <message>
        <location filename="mainwindow.ui" line="927"/>
        <source>Inline CSS</source>
        <translation></translation>
    </message>
    <message>
        <source>Style file:</source>
        <translation type="obsolete">Archivo de estilo:</translation>
    </message>
    <message>
        <location filename="mainwindow.ui" line="954"/>
        <location filename="mainwindow.ui" line="1357"/>
        <location filename="mainwindow.ui" line="1593"/>
        <source>Name of the referenced style file.</source>
        <translation>Nombre del archivo de estilo citado.</translation>
    </message>
    <message>
        <location filename="mainwindow.ui" line="957"/>
        <location filename="mainwindow.ui" line="1596"/>
        <source>highlight.css</source>
        <translation></translation>
    </message>
    <message>
        <source>Style include file:</source>
        <translation type="obsolete">Archivo de estilo a incluir:</translation>
    </message>
    <message>
        <location filename="mainwindow.ui" line="975"/>
        <location filename="mainwindow.ui" line="1631"/>
        <source>Path of the CSS include file.</source>
        <translation>Ruta del archivo CSS a incluir.</translation>
    </message>
    <message>
        <location filename="mainwindow.ui" line="982"/>
        <source>Select a CSS include file.</source>
        <translation>Seleccionar un archivo CSS a incluir.</translation>
    </message>
    <message>
        <location filename="mainwindow.ui" line="996"/>
        <source>CSS class prefix:</source>
        <translation>Prefijo de clase de CSS:</translation>
    </message>
    <message>
        <location filename="mainwindow.ui" line="1003"/>
        <source>Add a CSS class name prefix to avoid namespace clashes.</source>
        <translation>Agregue un prefijo de nombre de clase de CSS para evitar conflictos.</translation>
    </message>
    <message>
        <source>Tags and index files</source>
        <translation type="obsolete">Archivos de etiquetas e índice</translation>
    </message>
    <message>
        <location filename="mainwindow.ui" line="1038"/>
        <source>Generate an index file with hyperlinks to all outputted files.</source>
        <translation>Generar un archivo de indice con enlaces a todos los archivos de salida.</translation>
    </message>
    <message>
        <location filename="mainwindow.ui" line="1041"/>
        <source>Generate index file</source>
        <translation>Generar archivo de índice</translation>
    </message>
    <message>
        <location filename="mainwindow.ui" line="1061"/>
        <source>Read a ctags file and add the included metainformation as tooltips.
See ctags.sf.net for details.</source>
        <translation>Leer un archivo de ctags y agregar la metainformación incluida como aviso emergente.
Vea ctags.sf.net para más detalles.</translation>
    </message>
    <message>
        <source>Ctags file:</source>
        <translation type="obsolete">Archivo de ctags:</translation>
    </message>
    <message>
        <location filename="mainwindow.ui" line="1080"/>
        <source>Path of the ctags file.</source>
        <translation>Ruta del archivo de ctags.</translation>
    </message>
    <message>
        <location filename="mainwindow.ui" line="1093"/>
        <source>Choose a ctags file.</source>
        <translation>Elijir un archivo de ctags.</translation>
    </message>
    <message>
        <location filename="mainwindow.ui" line="1122"/>
        <source>Misc</source>
        <translation>Miscelaneo</translation>
    </message>
    <message>
        <location filename="mainwindow.ui" line="1141"/>
        <source>Add an achor to each line.</source>
        <translation>Agregar una ancla a cada linea.</translation>
    </message>
    <message>
        <location filename="mainwindow.ui" line="1144"/>
        <source>Add line anchors</source>
        <translation>Agregar ancla por linea</translation>
    </message>
    <message>
        <location filename="mainwindow.ui" line="1151"/>
        <source>Add the filename as prefix to the anchors.</source>
        <translation>Agregar el nombre de archivo como prefijo a las anclas.</translation>
    </message>
    <message>
        <location filename="mainwindow.ui" line="1154"/>
        <source>Include file name in anchor</source>
        <translation>Incluir el nombre de archivo en el ancla</translation>
    </message>
    <message>
        <location filename="mainwindow.ui" line="1161"/>
        <source>Output the lines within an ordered list.</source>
        <translation>Producir las lineas de salida dentro de una lista ordenada.</translation>
    </message>
    <message>
        <source>Ordered list</source>
        <translation type="obsolete">Lista ordenada</translation>
    </message>
    <message>
        <location filename="mainwindow.ui" line="1178"/>
        <source>Add &amp;lt;pre&amp;gt; tags to the output, if the flag &quot;No document header and footer&quot; is selected.</source>
        <translation>Agregar etiquetas &amp;lt;pre&amp;gt; a la salida, si la opción &quot;Sin cabecera ni pie de página&quot; está seleccionada.</translation>
    </message>
    <message>
        <source>Enclose in &lt;pre&gt;</source>
        <translation type="obsolete">Meter entre &amp;lt;pre&amp;gt;</translation>
    </message>
    <message>
        <source>LaTeX options</source>
        <translation type="obsolete">Opciones de LaTeX</translation>
    </message>
    <message>
        <location filename="mainwindow.ui" line="1209"/>
        <source>Replace quotes by dq sequences.</source>
        <translation>Reemplazar comillas por sucesiones de dobles comillas.</translation>
    </message>
    <message>
        <location filename="mainwindow.ui" line="1212"/>
        <source>Escape quotes</source>
        <translation>Sobrepasar comillas</translation>
    </message>
    <message>
        <location filename="mainwindow.ui" line="1219"/>
        <source>Make output Babel compatible.</source>
        <translation>Hacer que la salida se compatible con Babel.</translation>
    </message>
    <message>
        <source>Babel compatibility</source>
        <translation type="obsolete">Compatibilidad con Babel</translation>
    </message>
    <message>
        <location filename="mainwindow.ui" line="1229"/>
        <source>Replace default symbols (brackets, tilde) by nice redefinitions.</source>
        <translation>Reemplazar símbolos por defecto (llaves, corchetes, tildes) por redefiniciones apropiadas.</translation>
    </message>
    <message>
        <source>Pretty symbols</source>
        <translation type="obsolete">Símbolos lindos</translation>
    </message>
    <message>
        <location filename="mainwindow.ui" line="1242"/>
        <source>Embed style (defs)</source>
        <translation>Incrustar estilo</translation>
    </message>
    <message>
        <location filename="mainwindow.ui" line="1261"/>
        <source>Name of the referenced  style file.</source>
        <translation>Nombre del archivo de estilo citado.</translation>
    </message>
    <message>
        <location filename="mainwindow.ui" line="1264"/>
        <location filename="mainwindow.ui" line="1360"/>
        <source>highlight.sty</source>
        <translation></translation>
    </message>
    <message>
        <source>Style include:</source>
        <translation type="obsolete">Incluir estilo:</translation>
    </message>
    <message>
        <location filename="mainwindow.ui" line="742"/>
        <source>Set encoding:</source>
        <translation type="unfinished"></translation>
    </message>
    <message>
        <location filename="mainwindow.ui" line="253"/>
        <source>Output destination:</source>
        <translation>Destino de salida</translation>
    </message>
    <message>
        <location filename="mainwindow.ui" line="941"/>
        <location filename="mainwindow.ui" line="1251"/>
        <location filename="mainwindow.ui" line="1347"/>
        <location filename="mainwindow.ui" line="1583"/>
        <source>Stylesheet file:</source>
        <translation type="unfinished"></translation>
    </message>
    <message>
        <location filename="mainwindow.ui" line="1275"/>
        <location filename="mainwindow.ui" line="1371"/>
        <location filename="mainwindow.ui" line="1607"/>
        <source>Stylesheet include file:</source>
        <translation type="unfinished"></translation>
    </message>
    <message>
        <location filename="mainwindow.ui" line="1065"/>
        <source>Read ctags file:</source>
        <translation type="unfinished"></translation>
    </message>
    <message>
        <location filename="mainwindow.ui" line="20"/>
        <source>Highlight</source>
        <translation type="unfinished"></translation>
    </message>
    <message>
        <location filename="mainwindow.ui" line="154"/>
        <source>Files</source>
        <translation type="unfinished"></translation>
    </message>
    <message>
        <location filename="mainwindow.ui" line="368"/>
        <source>Paste clipboard content into the preview window.</source>
        <translation type="unfinished"></translation>
    </message>
    <message>
        <location filename="mainwindow.ui" line="371"/>
        <source>Paste from clipboard</source>
        <translation type="unfinished"></translation>
    </message>
    <message>
        <location filename="mainwindow.ui" line="413"/>
        <source>Copy highlighted code into the clipboard.</source>
        <translation type="unfinished"></translation>
    </message>
    <message>
        <location filename="mainwindow.ui" line="416"/>
        <source>Copy preview to clipboard</source>
        <translation type="unfinished"></translation>
    </message>
    <message>
        <location filename="mainwindow.ui" line="384"/>
        <source>Select syntax:</source>
        <translation type="unfinished"></translation>
    </message>
    <message>
        <location filename="mainwindow.ui" line="108"/>
        <source>&amp;Windows</source>
        <translation type="unfinished"></translation>
    </message>
    <message>
        <location filename="mainwindow.ui" line="128"/>
        <source>Highlighting options</source>
        <translation type="unfinished"></translation>
    </message>
    <message>
        <location filename="mainwindow.ui" line="391"/>
        <source>Select the correct syntax of the code snippet.</source>
        <translation type="unfinished"></translation>
    </message>
    <message>
        <location filename="mainwindow.ui" line="437"/>
        <source>Plug-ins</source>
        <translation type="unfinished"></translation>
    </message>
    <message>
        <location filename="mainwindow.ui" line="446"/>
        <source>Add plug-in to pool</source>
        <translation type="unfinished"></translation>
    </message>
    <message>
        <location filename="mainwindow.ui" line="470"/>
        <source>Description</source>
        <translation type="unfinished"></translation>
    </message>
    <message>
        <location filename="mainwindow.ui" line="476"/>
        <source>Shows decription of a selected plug-in script.</source>
        <translation type="unfinished"></translation>
    </message>
    <message>
        <location filename="mainwindow.ui" line="479"/>
        <source>Plug-In description</source>
        <translation type="unfinished"></translation>
    </message>
    <message>
        <location filename="mainwindow.ui" line="637"/>
        <source>BBCode</source>
        <translation type="unfinished"></translation>
    </message>
    <message>
        <location filename="mainwindow.ui" line="900"/>
        <source>Stylesheets</source>
        <translation type="unfinished"></translation>
    </message>
    <message>
        <location filename="mainwindow.ui" line="968"/>
        <source>Include:</source>
        <translation type="unfinished"></translation>
    </message>
    <message>
        <location filename="mainwindow.ui" line="1032"/>
        <source>Index/ctags</source>
        <translation type="unfinished"></translation>
    </message>
    <message>
        <location filename="mainwindow.ui" line="1134"/>
        <source>Line numbering options:</source>
        <translation type="unfinished"></translation>
    </message>
    <message>
        <location filename="mainwindow.ui" line="1164"/>
        <source>Output as ordered list</source>
        <translation type="unfinished"></translation>
    </message>
    <message>
        <location filename="mainwindow.ui" line="1181"/>
        <source>Enclose in pre tags</source>
        <translation type="unfinished"></translation>
    </message>
    <message>
        <location filename="mainwindow.ui" line="1222"/>
        <source>Add Babel compatibility</source>
        <translation type="unfinished"></translation>
    </message>
    <message>
        <location filename="mainwindow.ui" line="1232"/>
        <source>Add pretty symbols</source>
        <translation type="unfinished"></translation>
    </message>
    <message>
        <location filename="mainwindow.ui" line="1299"/>
        <location filename="mainwindow.ui" line="1395"/>
        <source>Path of the style include file.</source>
        <translation>Ruta del archivo de estilo a incluir.</translation>
    </message>
    <message>
        <location filename="mainwindow.ui" line="1306"/>
        <location filename="mainwindow.ui" line="1402"/>
        <location filename="mainwindow.ui" line="1638"/>
        <source>Select a style include file.</source>
        <translation>Seleccione un archivo de estilo a incluir.</translation>
    </message>
    <message>
        <source>TeX options</source>
        <translation type="obsolete">Opciones de TeX</translation>
    </message>
    <message>
        <location filename="mainwindow.ui" line="1338"/>
        <source>Embed style (macros)</source>
        <translation>Estilo de incrustación (macros)</translation>
    </message>
    <message>
        <source>RTF options</source>
        <translation type="obsolete">Opciones de RTF</translation>
    </message>
    <message>
        <location filename="mainwindow.ui" line="1431"/>
        <source>Add character stylesheets with formatting information.
You can select the stylesheets in your word processor to reformat additional text.</source>
        <translation>Agregar hojas de estilo de caracteres con informacion de formato.
Puede selecionar la hoja de estilo en su procesador de textos para dar formato nuevamente a texto adicional.</translation>
    </message>
    <message>
        <location filename="mainwindow.ui" line="1435"/>
        <source>Add character styles</source>
        <translation>Agregar estilos de caracteres</translation>
    </message>
    <message>
        <location filename="mainwindow.ui" line="1444"/>
        <source>Page size:</source>
        <translation>Tamaño de paǵina:</translation>
    </message>
    <message>
        <location filename="mainwindow.ui" line="1451"/>
        <source>Select a page size.</source>
        <translation>Seleccionar un tamaño de página.</translation>
    </message>
    <message>
        <location filename="mainwindow.ui" line="1458"/>
        <source>A3</source>
        <translation></translation>
    </message>
    <message>
        <location filename="mainwindow.ui" line="1463"/>
        <source>A4</source>
        <translation></translation>
    </message>
    <message>
        <location filename="mainwindow.ui" line="1468"/>
        <source>A5</source>
        <translation></translation>
    </message>
    <message>
        <location filename="mainwindow.ui" line="1473"/>
        <source>B4</source>
        <translation></translation>
    </message>
    <message>
        <location filename="mainwindow.ui" line="1478"/>
        <source>B5</source>
        <translation></translation>
    </message>
    <message>
        <location filename="mainwindow.ui" line="1483"/>
        <source>B6</source>
        <translation></translation>
    </message>
    <message>
        <location filename="mainwindow.ui" line="1488"/>
        <source>Letter</source>
        <translation>Carta</translation>
    </message>
    <message>
        <location filename="mainwindow.ui" line="1493"/>
        <source>Legal</source>
        <translation>Oficio</translation>
    </message>
    <message>
        <source>SVG options</source>
        <translation type="obsolete">Opciones de SVG</translation>
    </message>
    <message>
        <location filename="mainwindow.ui" line="1520"/>
        <source>Image size:</source>
        <translation>Tamaño de la imagen:</translation>
    </message>
    <message>
        <location filename="mainwindow.ui" line="1529"/>
        <source>Width:</source>
        <translation>Ancho:</translation>
    </message>
    <message>
        <location filename="mainwindow.ui" line="1545"/>
        <source>Enter the SVG width (may contain units).</source>
        <translation>Introducir el ancho de SVG (puede incluir unidades).</translation>
    </message>
    <message>
        <location filename="mainwindow.ui" line="1552"/>
        <source>Height:</source>
        <translation>Alto:</translation>
    </message>
    <message>
        <location filename="mainwindow.ui" line="1562"/>
        <source>Enter the SVG height (may contain units).</source>
        <translation>Introducir el alto de SVG (puede incluir unidades).</translation>
    </message>
    <message>
        <location filename="mainwindow.ui" line="1667"/>
        <source>No options defined.</source>
        <translation>No hay opciones definidas.</translation>
    </message>
    <message>
        <location filename="mainwindow.ui" line="1692"/>
        <source>Formatting</source>
        <translation>Formato</translation>
    </message>
    <message>
        <location filename="mainwindow.ui" line="1706"/>
        <source>Color theme:</source>
        <translation>Tema de color:</translation>
    </message>
    <message>
        <location filename="mainwindow.ui" line="1722"/>
        <source>Select a colour theme.</source>
        <translation>Seleccionar un tema de color.</translation>
    </message>
    <message>
        <location filename="mainwindow.ui" line="1733"/>
        <source>Reformat and indent your code.
This feature is enabled tor C, C++, C# and Java code.</source>
        <translation>Dar formato nuevamente e indentar su código.
Esta propiedad esta habilitada para código en C, C++, C# y Java.</translation>
    </message>
    <message>
        <location filename="mainwindow.ui" line="1737"/>
        <source>Reformat:</source>
        <translation>Dar formato nuevamente:</translation>
    </message>
    <message>
        <location filename="mainwindow.ui" line="1750"/>
        <source>Choose a formatting scheme.</source>
        <translation>Elija un esquema de formato.</translation>
    </message>
    <message>
        <location filename="mainwindow.ui" line="1754"/>
        <source>Allman</source>
        <translation type="unfinished"></translation>
    </message>
    <message>
        <location filename="mainwindow.ui" line="1759"/>
        <source>Banner</source>
        <translation type="unfinished"></translation>
    </message>
    <message>
        <location filename="mainwindow.ui" line="1764"/>
        <source>GNU</source>
        <translation type="unfinished"></translation>
    </message>
    <message>
        <location filename="mainwindow.ui" line="1769"/>
        <source>Horstmann</source>
        <translation type="unfinished"></translation>
    </message>
    <message>
        <location filename="mainwindow.ui" line="1774"/>
        <source>Java</source>
        <translation type="unfinished"></translation>
    </message>
    <message>
        <location filename="mainwindow.ui" line="1779"/>
        <source>K&amp;R</source>
        <translation type="unfinished"></translation>
    </message>
    <message>
        <location filename="mainwindow.ui" line="1784"/>
        <source>Linux</source>
        <translation type="unfinished"></translation>
    </message>
    <message>
        <location filename="mainwindow.ui" line="1789"/>
        <source>OTBS</source>
        <translation type="unfinished"></translation>
    </message>
    <message>
        <location filename="mainwindow.ui" line="1794"/>
        <source>Stroustrup</source>
        <translation type="unfinished"></translation>
    </message>
    <message>
        <location filename="mainwindow.ui" line="1799"/>
        <source>Whitesmith</source>
        <translation type="unfinished"></translation>
    </message>
    <message>
        <location filename="mainwindow.ui" line="1811"/>
        <source>Change the keyword case.</source>
        <translation>Cambiar mayúsculas/minúsculas en palabras reservadas.</translation>
    </message>
    <message>
        <location filename="mainwindow.ui" line="1814"/>
        <source>Keyword case:</source>
        <translation>Mayúsculas/minúsculas de palabras reservadas:</translation>
    </message>
    <message>
        <location filename="mainwindow.ui" line="1827"/>
        <source>Select a keyword case.</source>
        <translation>Seleccione un estilo de mayúsculas/minúsculas.</translation>
    </message>
    <message>
        <location filename="mainwindow.ui" line="1831"/>
        <source>UPPER</source>
        <translation>MAYÚSCULAS</translation>
    </message>
    <message>
        <location filename="mainwindow.ui" line="1836"/>
        <source>lower</source>
        <translation>minúsculas</translation>
    </message>
    <message>
        <location filename="mainwindow.ui" line="1841"/>
        <source>Capitalize</source>
        <translation>Primera Letra Mayúscula</translation>
    </message>
    <message>
        <location filename="mainwindow.ui" line="1859"/>
        <source>Tab width:</source>
        <translation>Ancho de tabulador:</translation>
    </message>
    <message>
        <location filename="mainwindow.ui" line="1869"/>
        <source>Enter the number of spaces which replace a tab.
Set the width to 0 to keep tabs.</source>
        <translation>Introducir el número de espacios que reemplazaran un tabulador.
En caso de ser 0 se mantendrán los tabuladores.</translation>
    </message>
    <message>
        <location filename="mainwindow.ui" line="1884"/>
        <source>Enable line wrapping.</source>
        <translation>Habilitar romper lineas.</translation>
    </message>
    <message>
        <location filename="mainwindow.ui" line="1887"/>
        <source>Line wrapping</source>
        <translation>Romper lineas</translation>
    </message>
    <message>
        <location filename="mainwindow.ui" line="1894"/>
        <source>Enter the maximum line length.</source>
        <translation>Introducir longitud máxima de linea.</translation>
    </message>
    <message>
        <location filename="mainwindow.ui" line="1913"/>
        <source>Indent statements and function parameters after wrapping.</source>
        <translation>Indentar instrucciones y parámetros de funciones después de romper la linea.</translation>
    </message>
    <message>
        <location filename="mainwindow.ui" line="1916"/>
        <source>Intelligent wrapping</source>
        <translation>Rompido inteligente</translation>
    </message>
    <message>
        <location filename="mainwindow.ui" line="1950"/>
        <source>Font name:</source>
        <translation>Nombre de la fuente:</translation>
    </message>
    <message>
        <source>Select or enter the font name.</source>
        <translation type="obsolete">Seleccionar o introduzcir el nombre de la fuente.</translation>
    </message>
    <message>
        <location filename="mainwindow.ui" line="1967"/>
        <source>Font size:</source>
        <translation>Tamaño de la fuente:</translation>
    </message>
    <message>
        <location filename="mainwindow.ui" line="1983"/>
        <source>Enter the font size.</source>
        <translation>Introducir el tamaño de la fuente.</translation>
    </message>
    <message>
        <location filename="mainwindow.ui" line="2056"/>
        <source>Visit andre-simon.de</source>
        <translation type="unfinished"></translation>
    </message>
    <message>
        <location filename="mainwindow.ui" line="2067"/>
        <source>&amp;Dock floating panels</source>
        <translation type="unfinished"></translation>
    </message>
    <message>
        <location filename="mainwindow.ui" line="33"/>
        <source>Preview</source>
        <translation>Previsualización</translation>
    </message>
    <message>
        <location filename="mainwindow.ui" line="338"/>
        <source>Start the conversion of your input files.</source>
        <translation>Comenzar la conversión de los archivos de entrada.</translation>
    </message>
    <message>
        <location filename="mainwindow.ui" line="341"/>
        <source>Convert files</source>
        <translation>Convertir archivos</translation>
    </message>
    <message>
        <location filename="mainwindow.ui" line="351"/>
        <source>Copy highlighted code of the seleted file into the clipboard.</source>
        <translation>Copiar codigo resaltado del archivo seleccionado al portapapeles.</translation>
    </message>
    <message>
        <location filename="mainwindow.ui" line="362"/>
        <source>Clipboard</source>
        <translation>Portapapeles</translation>
    </message>
    <message>
        <location filename="mainwindow.ui" line="354"/>
        <source>Copy file to clipboard</source>
        <translation type="unfinished"></translation>
    </message>
    <message>
        <location filename="mainwindow.ui" line="443"/>
        <source>Choose a plug-in script.</source>
        <translation type="unfinished"></translation>
    </message>
    <message>
        <location filename="mainwindow.ui" line="457"/>
        <source>List of plug-ins. Toggle checkbox to enable the scripts.</source>
        <translation type="unfinished"></translation>
    </message>
    <message>
        <location filename="mainwindow.ui" line="503"/>
        <source>Remove the selected plug-ins.</source>
        <translation type="unfinished"></translation>
    </message>
    <message>
        <location filename="mainwindow.ui" line="513"/>
        <source>Remove all plug-ins.</source>
        <translation type="unfinished"></translation>
    </message>
    <message>
        <location filename="mainwindow.ui" line="58"/>
        <source>Output progress:</source>
        <translation type="unfinished"></translation>
    </message>
    <message>
        <location filename="mainwindow.ui" line="86"/>
        <source>&amp;File</source>
        <translation>&amp;Archivo</translation>
    </message>
    <message>
        <location filename="mainwindow.ui" line="94"/>
        <source>&amp;Help</source>
        <translation>Ay&amp;uda</translation>
    </message>
    <message>
        <location filename="mainwindow.ui" line="1960"/>
        <source>Select or enter the font name. HTML supports a list of fonts, separated with comma.</source>
        <translation type="unfinished"></translation>
    </message>
    <message>
        <location filename="mainwindow.ui" line="1998"/>
        <source>&amp;Open files</source>
        <translation>Ab&amp;rir archivos</translation>
    </message>
    <message>
        <location filename="mainwindow.ui" line="2003"/>
        <source>&amp;Exit</source>
        <translation>&amp;Salir</translation>
    </message>
    <message>
        <location filename="mainwindow.ui" line="2008"/>
        <source>&amp;Load</source>
        <translation>&amp;Cargar</translation>
    </message>
    <message>
        <location filename="mainwindow.ui" line="2013"/>
        <source>&amp;Save</source>
        <translation>&amp;Guardar</translation>
    </message>
    <message>
        <location filename="mainwindow.ui" line="2018"/>
        <source>Load &amp;default project</source>
        <translation>Cargar proyecto por &amp;defecto</translation>
    </message>
    <message>
        <location filename="mainwindow.ui" line="2023"/>
        <source>Readme</source>
        <translation>Leeme</translation>
    </message>
    <message>
        <location filename="mainwindow.ui" line="2028"/>
        <source>&amp;Tips</source>
        <translation>A&amp;visos</translation>
    </message>
    <message>
        <location filename="mainwindow.ui" line="2036"/>
        <source>&amp;Changelog</source>
        <translation>&amp;Bitácora de cambios</translation>
    </message>
    <message>
        <location filename="mainwindow.ui" line="2041"/>
        <source>&amp;License</source>
        <translation>&amp;Licencia</translation>
    </message>
    <message>
        <location filename="mainwindow.ui" line="2046"/>
        <source>&amp;About Highlight</source>
        <translation>&amp;Acerca de Highlight</translation>
    </message>
    <message>
        <location filename="mainwindow.ui" line="2051"/>
        <source>About &amp;translations</source>
        <translation type="unfinished"></translation>
    </message>
</context>
<context>
    <name>ShowTextFile</name>
    <message>
        <location filename="showtextfile.ui" line="17"/>
        <source>Show text</source>
        <translation>Mostrar texto</translation>
    </message>
    <message>
        <location filename="showtextfile.ui" line="37"/>
        <source>TextLabel</source>
        <translation>EtiquetaDeTexto</translation>
    </message>
    <message>
        <location filename="showtextfile.ui" line="69"/>
        <source>OK</source>
        <translation>OK</translation>
    </message>
</context>
<context>
    <name>io_report</name>
    <message>
        <location filename="io_report.ui" line="14"/>
        <source>Error summary</source>
        <translation>Resumen de Error</translation>
    </message>
    <message>
        <location filename="io_report.ui" line="24"/>
        <source>Input errors:</source>
        <translation>Errores de entrada:</translation>
    </message>
    <message>
        <location filename="io_report.ui" line="34"/>
        <source>Remove files above from input file list</source>
        <translation>Remover archivos mencionados de la lista de archivos de entrada</translation>
    </message>
    <message>
        <location filename="io_report.ui" line="48"/>
        <source>Output errors:</source>
        <translation>Errores de salida:</translation>
    </message>
    <message>
        <location filename="io_report.ui" line="65"/>
        <source>Reformatting not possible:</source>
        <translation>No es posible dar formato nuevamente:</translation>
    </message>
</context>
</TS>
